@@ -23,9 +23,10 @@ void PGrnApplyOptionValues(Relation index,
 						   grn_obj **normalizer,
 						   const char *defaultNormalizerName,
 						   grn_obj **tokenFilters,
-						   grn_table_flags *lexiconType);
+						   grn_table_flags *lexiconType,
+						   grn_column_flags *indexFlags);
 
 grn_expr_flags PGrnOptionsGetExprParseFlags(Relation index);
 
-bytea *pgroonga_options_raw(Datum reloptions,
-							bool validate);
+bytea *pgroonga_options(Datum reloptions,
+						bool validate);
